
how_to = '''
# just add this 1 line.
from VicksTor import VicksTor 

from flask import Flask
app = Flask(__name__)

@app.route('/')
def hello_world():
    return 'Hello, World!'

if __name__ == '__main__':
    app.run()
'''

print(how_to)



from setuptools import setup

setup(
    name = 'VicksTor', # while installing pacakge
    version = '0.0.6',
    description = 'Hosting Flask on Tor Browser.',
    long_description = open('Readme.txt').read(),
    url = 'https://github.com/imvickykumar999/Flask-XAMPP-Onion-Host',
    author = 'Vicky Kumar',
    keywords = ['Hosting', 'Flask', 'Tor Browser'],
    license = 'MIT',
    packages = ['VicksTor'], # while importing package
)




import requests
URL = 'https://raw.githubusercontent.com/imvickykumar999/Flask-XAMPP-Onion-Host/main/Tutorial%20Files/VicksTor.py'

r = requests.get(URL, allow_redirects=True)
open('VicksTor.py', 'wb').write(r.content)
